@@ -41,11 +41,11 @@ class BaseNode(object):
             cmd = ' '.join([prog]+args)
 
 
-            logline = ','.join([ timestr, path, cmd ])
+            logline = ','.join([ timestr, path, cmd ])+'\n'
 
             # Update the log file
             with open(filename,'a') as fho:
-                fho.write( logline+os.linesep )
+                fho.write( logline )
 
             # Truncate history file, if necesary
             size = os.stat(filename).st_size
@@ -63,7 +63,8 @@ class BaseNode(object):
                 remainder = ''
                 with open(filename) as fhi:
                     cur = 0
-                    for line in fhi:
+                    while 1:
+                        line = fhi.readline()
                         cur += len(line)
                         if cur >= cutsize: break
                     remainder = fhi.read()
@@ -120,7 +121,7 @@ class Function(BaseNode):
         `=sys.argv[1:]`). The return value is identical to
         the return value of the reference function.
         """
-        if prog is None: prog = sys.argv[0]
+        if prog is None: prog = os.path.basename( sys.argv[0] )
         if args is None: args = sys.argv[1:]
         BaseNode._log(self,prog=prog,args=args)
 
@@ -145,7 +146,7 @@ class Node(BaseNode):
         the return value of the reference function.
         """
 
-        if prog is None: prog = sys.argv[0]
+        if prog is None: prog = os.path.basename( sys.argv[0] )
         if args is None: args = sys.argv[1:]
 
         _EXTRA_KWD = '_ARGPEXT_EXTRA_KWD'
@@ -249,7 +250,7 @@ class Categorical(object):
                     raise InitializationError('invalid size %d for %s item number %d' % ( len(q), type(q).__name__, count ) )
 
                 if not isinstance(q[1],Unit):
-                    q[1] = Unit(value=q[1])
+                    q = [q[0],Unit(value=q[1])]
                 item = q
             else:
                 raise InitializationError('invalid type (%s) for mapping item number %d.' % ( type(q).__name__, count ) )
